DeriveNode

Derive Macro DeriveNode 

#[derive(DeriveNode)]
Derive the Node trait for a newtype wrapper around Handle.

Use this for non-element node types that cannot have children or attributes (e.g., TextNode, CommentNode).

Example

#[derive(Copy, Clone, Node)]
pub struct TextNode(Handle);

Generates impl Node for TextNode and impl Debug for TextNode.