MediaReadyState

Enum MediaReadyState 

pub enum MediaReadyState {
    HaveNothing = 0,
    HaveMetadata = 1,
    HaveCurrentData = 2,
    HaveFutureData = 3,
    HaveEnoughData = 4,
}
Media element ready states.

Chrome equivalent: HTMLMediaElement::ReadyState.

Variants



HaveNothing = 0

No information about the media resource.



HaveMetadata = 1

Enough data to know duration and dimensions.



HaveCurrentData = 2

Data for the current playback position, but not enough for playback.



HaveFutureData = 3

Enough data to play at current position for a short while.



HaveEnoughData = 4

Enough data to play through to the end without buffering.