Modifiers

Struct Modifiers 

pub struct Modifiers(/* private fields */);
Modifier key and button state, carried on every input event.

Chrome equivalent: WebInputEvent::modifiers_ bitfield.

if event.modifiers.ctrl() && event.modifiers.shift() {
    // Ctrl+Shift is held
}

Implementations

Source

impl Modifiers

pub const EMPTY: Self

Empty — no modifiers held.

pub const fn from_bits(bits: u16) -> Self

Create from raw bits.

pub const fn bits(self) -> u16

Get the raw bits.

pub const fn shift(self) -> bool

Shift key is held.

pub const fn ctrl(self) -> bool

Ctrl key is held (Control on Mac).

pub const fn alt(self) -> bool

Alt key is held (Option on Mac).

pub const fn meta(self) -> bool

Meta key is held (Win on Windows, Cmd on Mac).

pub const fn caps_lock(self) -> bool

Caps Lock is active.

pub const fn num_lock(self) -> bool

Num Lock is active.

pub const fn left_button(self) -> bool

Left mouse button is currently held.

pub const fn right_button(self) -> bool

Right mouse button is currently held.

pub const fn middle_button(self) -> bool

Middle mouse button is currently held.

pub const fn is_auto_repeat(self) -> bool

This is an auto-repeat key event (key held down).

pub const fn with_shift(self) -> Self

pub const fn with_ctrl(self) -> Self

pub const fn with_alt(self) -> Self

pub const fn with_meta(self) -> Self

pub const fn with_caps_lock(self) -> Self

pub const fn with_num_lock(self) -> Self

pub const fn with_left_button(self) -> Self

pub const fn with_right_button(self) -> Self

pub const fn with_middle_button(self) -> Self

pub const fn with_auto_repeat(self) -> Self

pub const fn union(self, other: Self) -> Self

Combine two modifier sets.

pub const fn contains(self, other: Self) -> bool

Check if all bits in other are set in self.