pub struct TransformData {
pub translate_x: f32,
pub translate_y: f32,
pub scroll_node: Option<u32>,
}Expand description
2D transform data for PushTransform.
Fields
translate_x: f32Translation in X.
translate_y: f32Translation in Y.
scroll_node: Option<u32>If this transform is a scroll translate, the DOM node that owns it. The compositor can override this with its own offset without repainting.