UI

Struct UI 

pub struct UI {
Show 19 fields pub animation_delay: OwnedList<Time>, pub animation_direction: OwnedList<AnimationDirection>, pub animation_duration: OwnedList<GenericAnimationDuration<Time>>, pub animation_fill_mode: OwnedList<AnimationFillMode>, pub animation_iteration_count: OwnedList<AnimationIterationCount>, pub animation_name: OwnedList<AnimationName>, pub animation_play_state: OwnedList<AnimationPlayState>, pub animation_range_end: OwnedList<GenericAnimationRangeEnd<LengthPercentage>>, pub animation_range_start: OwnedList<GenericAnimationRangeStart<LengthPercentage>>, pub animation_timeline: OwnedList<GenericAnimationTimeline<LengthPercentage>>, pub animation_timing_function: OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>, pub transition_behavior: OwnedList<TransitionBehavior>, pub transition_delay: OwnedList<Time>, pub transition_duration: OwnedList<Time>, pub transition_property: OwnedList<TransitionProperty>, pub transition_timing_function: OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>, pub animation_composition: OwnedList<AnimationComposition>, pub view_transition_class: ViewTransitionClass, pub view_transition_name: ViewTransitionName,
}
The UI style struct.

Fields

animation_delay: OwnedList<Time>

The animation-delay computed value.

animation_direction: OwnedList<AnimationDirection>

The animation-direction computed value.

animation_duration: OwnedList<GenericAnimationDuration<Time>>

The animation-duration computed value.

animation_fill_mode: OwnedList<AnimationFillMode>

The animation-fill-mode computed value.

animation_iteration_count: OwnedList<AnimationIterationCount>

The animation-iteration-count computed value.

animation_name: OwnedList<AnimationName>

The animation-name computed value.

animation_play_state: OwnedList<AnimationPlayState>

The animation-play-state computed value.

animation_range_end: OwnedList<GenericAnimationRangeEnd<LengthPercentage>>

The animation-range-end computed value.

animation_range_start: OwnedList<GenericAnimationRangeStart<LengthPercentage>>

The animation-range-start computed value.

animation_timeline: OwnedList<GenericAnimationTimeline<LengthPercentage>>

The animation-timeline computed value.

animation_timing_function: OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>

The animation-timing-function computed value.

transition_behavior: OwnedList<TransitionBehavior>

The transition-behavior computed value.

transition_delay: OwnedList<Time>

The transition-delay computed value.

transition_duration: OwnedList<Time>

The transition-duration computed value.

transition_property: OwnedList<TransitionProperty>

The transition-property computed value.

transition_timing_function: OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>

The transition-timing-function computed value.

animation_composition: OwnedList<AnimationComposition>

The animation-composition computed value.

view_transition_class: ViewTransitionClass

The view-transition-class computed value.

view_transition_name: ViewTransitionName

The view-transition-name computed value.

Implementations

Source

impl UI

pub fn set_animation_delay(&mut self, v: OwnedList<Time>)

Set animation-delay.

pub fn copy_animation_delay_from(&mut self, other: &UI)

Set animation-delay from other struct.

pub fn reset_animation_delay(&mut self, other: &UI)

Reset animation-delay from the initial struct.

pub fn clone_animation_delay(&self) -> OwnedList<Time>

Get the computed value for animation-delay.

pub fn animation_delay_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-delay.

pub fn animation_delay_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_delay_at(&self, index: usize) -> Time

If this longhand is indexed, get the element at given index.

pub fn set_animation_direction(&mut self, v: OwnedList<AnimationDirection>)

Set animation-direction.

pub fn copy_animation_direction_from(&mut self, other: &UI)

Set animation-direction from other struct.

pub fn reset_animation_direction(&mut self, other: &UI)

Reset animation-direction from the initial struct.

pub fn clone_animation_direction(&self) -> OwnedList<AnimationDirection>

Get the computed value for animation-direction.

pub fn animation_direction_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-direction.

pub fn animation_direction_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_direction_at(&self, index: usize) -> AnimationDirection

If this longhand is indexed, get the element at given index.

pub fn set_animation_duration( &mut self, v: OwnedList<GenericAnimationDuration<Time>>, )

Set animation-duration.

pub fn copy_animation_duration_from(&mut self, other: &UI)

Set animation-duration from other struct.

pub fn reset_animation_duration(&mut self, other: &UI)

Reset animation-duration from the initial struct.

pub fn clone_animation_duration( &self, ) -> OwnedList<GenericAnimationDuration<Time>>

Get the computed value for animation-duration.

pub fn animation_duration_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-duration.

pub fn animation_duration_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_duration_at( &self, index: usize, ) -> GenericAnimationDuration<Time>

If this longhand is indexed, get the element at given index.

pub fn set_animation_fill_mode(&mut self, v: OwnedList<AnimationFillMode>)

Set animation-fill-mode.

pub fn copy_animation_fill_mode_from(&mut self, other: &UI)

Set animation-fill-mode from other struct.

pub fn reset_animation_fill_mode(&mut self, other: &UI)

Reset animation-fill-mode from the initial struct.

pub fn clone_animation_fill_mode(&self) -> OwnedList<AnimationFillMode>

Get the computed value for animation-fill-mode.

pub fn animation_fill_mode_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-fill-mode.

pub fn animation_fill_mode_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_fill_mode_at(&self, index: usize) -> AnimationFillMode

If this longhand is indexed, get the element at given index.

pub fn set_animation_iteration_count( &mut self, v: OwnedList<AnimationIterationCount>, )

Set animation-iteration-count.

pub fn copy_animation_iteration_count_from(&mut self, other: &UI)

Set animation-iteration-count from other struct.

pub fn reset_animation_iteration_count(&mut self, other: &UI)

Reset animation-iteration-count from the initial struct.

pub fn clone_animation_iteration_count( &self, ) -> OwnedList<AnimationIterationCount>

Get the computed value for animation-iteration-count.

pub fn animation_iteration_count_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-iteration-count.

pub fn animation_iteration_count_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_iteration_count_at( &self, index: usize, ) -> AnimationIterationCount

If this longhand is indexed, get the element at given index.

pub fn set_animation_name(&mut self, v: OwnedList<AnimationName>)

Set animation-name.

pub fn copy_animation_name_from(&mut self, other: &UI)

Set animation-name from other struct.

pub fn reset_animation_name(&mut self, other: &UI)

Reset animation-name from the initial struct.

pub fn clone_animation_name(&self) -> OwnedList<AnimationName>

Get the computed value for animation-name.

pub fn animation_name_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-name.

pub fn animation_name_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_name_at(&self, index: usize) -> AnimationName

If this longhand is indexed, get the element at given index.

pub fn set_animation_play_state(&mut self, v: OwnedList<AnimationPlayState>)

Set animation-play-state.

pub fn copy_animation_play_state_from(&mut self, other: &UI)

Set animation-play-state from other struct.

pub fn reset_animation_play_state(&mut self, other: &UI)

Reset animation-play-state from the initial struct.

pub fn clone_animation_play_state(&self) -> OwnedList<AnimationPlayState>

Get the computed value for animation-play-state.

pub fn animation_play_state_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-play-state.

pub fn animation_play_state_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_play_state_at(&self, index: usize) -> AnimationPlayState

If this longhand is indexed, get the element at given index.

pub fn set_animation_range_end( &mut self, v: OwnedList<GenericAnimationRangeEnd<LengthPercentage>>, )

Set animation-range-end.

pub fn copy_animation_range_end_from(&mut self, other: &UI)

Set animation-range-end from other struct.

pub fn reset_animation_range_end(&mut self, other: &UI)

Reset animation-range-end from the initial struct.

pub fn clone_animation_range_end( &self, ) -> OwnedList<GenericAnimationRangeEnd<LengthPercentage>>

Get the computed value for animation-range-end.

pub fn animation_range_end_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-range-end.

pub fn animation_range_end_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_range_end_at( &self, index: usize, ) -> GenericAnimationRangeEnd<LengthPercentage>

If this longhand is indexed, get the element at given index.

pub fn set_animation_range_start( &mut self, v: OwnedList<GenericAnimationRangeStart<LengthPercentage>>, )

Set animation-range-start.

pub fn copy_animation_range_start_from(&mut self, other: &UI)

Set animation-range-start from other struct.

pub fn reset_animation_range_start(&mut self, other: &UI)

Reset animation-range-start from the initial struct.

pub fn clone_animation_range_start( &self, ) -> OwnedList<GenericAnimationRangeStart<LengthPercentage>>

Get the computed value for animation-range-start.

pub fn animation_range_start_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-range-start.

pub fn animation_range_start_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_range_start_at( &self, index: usize, ) -> GenericAnimationRangeStart<LengthPercentage>

If this longhand is indexed, get the element at given index.

pub fn set_animation_timeline( &mut self, v: OwnedList<GenericAnimationTimeline<LengthPercentage>>, )

Set animation-timeline.

pub fn copy_animation_timeline_from(&mut self, other: &UI)

Set animation-timeline from other struct.

pub fn reset_animation_timeline(&mut self, other: &UI)

Reset animation-timeline from the initial struct.

pub fn clone_animation_timeline( &self, ) -> OwnedList<GenericAnimationTimeline<LengthPercentage>>

Get the computed value for animation-timeline.

pub fn animation_timeline_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-timeline.

pub fn animation_timeline_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_timeline_at( &self, index: usize, ) -> GenericAnimationTimeline<LengthPercentage>

If this longhand is indexed, get the element at given index.

pub fn set_animation_timing_function( &mut self, v: OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>, )

Set animation-timing-function.

pub fn copy_animation_timing_function_from(&mut self, other: &UI)

Set animation-timing-function from other struct.

pub fn reset_animation_timing_function(&mut self, other: &UI)

Reset animation-timing-function from the initial struct.

pub fn clone_animation_timing_function( &self, ) -> OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>

Get the computed value for animation-timing-function.

pub fn animation_timing_function_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-timing-function.

pub fn animation_timing_function_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_timing_function_at( &self, index: usize, ) -> TimingFunction<i32, f32, PiecewiseLinearFunction>

If this longhand is indexed, get the element at given index.

pub fn set_transition_behavior(&mut self, v: OwnedList<TransitionBehavior>)

Set transition-behavior.

pub fn copy_transition_behavior_from(&mut self, other: &UI)

Set transition-behavior from other struct.

pub fn reset_transition_behavior(&mut self, other: &UI)

Reset transition-behavior from the initial struct.

pub fn clone_transition_behavior(&self) -> OwnedList<TransitionBehavior>

Get the computed value for transition-behavior.

pub fn transition_behavior_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for transition-behavior.

pub fn transition_behavior_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn transition_behavior_at(&self, index: usize) -> TransitionBehavior

If this longhand is indexed, get the element at given index.

pub fn set_transition_delay(&mut self, v: OwnedList<Time>)

Set transition-delay.

pub fn copy_transition_delay_from(&mut self, other: &UI)

Set transition-delay from other struct.

pub fn reset_transition_delay(&mut self, other: &UI)

Reset transition-delay from the initial struct.

pub fn clone_transition_delay(&self) -> OwnedList<Time>

Get the computed value for transition-delay.

pub fn transition_delay_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for transition-delay.

pub fn transition_delay_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn transition_delay_at(&self, index: usize) -> Time

If this longhand is indexed, get the element at given index.

pub fn set_transition_duration(&mut self, v: OwnedList<Time>)

Set transition-duration.

pub fn copy_transition_duration_from(&mut self, other: &UI)

Set transition-duration from other struct.

pub fn reset_transition_duration(&mut self, other: &UI)

Reset transition-duration from the initial struct.

pub fn clone_transition_duration(&self) -> OwnedList<Time>

Get the computed value for transition-duration.

pub fn transition_duration_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for transition-duration.

pub fn transition_duration_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn transition_duration_at(&self, index: usize) -> Time

If this longhand is indexed, get the element at given index.

pub fn set_transition_property(&mut self, v: OwnedList<TransitionProperty>)

Set transition-property.

pub fn copy_transition_property_from(&mut self, other: &UI)

Set transition-property from other struct.

pub fn reset_transition_property(&mut self, other: &UI)

Reset transition-property from the initial struct.

pub fn clone_transition_property(&self) -> OwnedList<TransitionProperty>

Get the computed value for transition-property.

pub fn transition_property_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for transition-property.

pub fn transition_property_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn transition_property_at(&self, index: usize) -> TransitionProperty

If this longhand is indexed, get the element at given index.

pub fn set_transition_timing_function( &mut self, v: OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>, )

Set transition-timing-function.

pub fn copy_transition_timing_function_from(&mut self, other: &UI)

Set transition-timing-function from other struct.

pub fn reset_transition_timing_function(&mut self, other: &UI)

Reset transition-timing-function from the initial struct.

pub fn clone_transition_timing_function( &self, ) -> OwnedList<TimingFunction<i32, f32, PiecewiseLinearFunction>>

Get the computed value for transition-timing-function.

pub fn transition_timing_function_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for transition-timing-function.

pub fn transition_timing_function_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn transition_timing_function_at( &self, index: usize, ) -> TimingFunction<i32, f32, PiecewiseLinearFunction>

If this longhand is indexed, get the element at given index.

pub fn set_animation_composition(&mut self, v: OwnedList<AnimationComposition>)

Set animation-composition.

pub fn copy_animation_composition_from(&mut self, other: &UI)

Set animation-composition from other struct.

pub fn reset_animation_composition(&mut self, other: &UI)

Reset animation-composition from the initial struct.

pub fn clone_animation_composition(&self) -> OwnedList<AnimationComposition>

Get the computed value for animation-composition.

pub fn animation_composition_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for animation-composition.

pub fn animation_composition_count(&self) -> usize

If this longhand is indexed, get the number of elements.

pub fn animation_composition_at(&self, index: usize) -> AnimationComposition

If this longhand is indexed, get the element at given index.

pub fn set_view_transition_class(&mut self, v: ViewTransitionClass)

Set view-transition-class.

pub fn copy_view_transition_class_from(&mut self, other: &UI)

Set view-transition-class from other struct.

pub fn reset_view_transition_class(&mut self, other: &UI)

Reset view-transition-class from the initial struct.

pub fn clone_view_transition_class(&self) -> ViewTransitionClass

Get the computed value for view-transition-class.

pub fn view_transition_class_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for view-transition-class.

pub fn set_view_transition_name(&mut self, v: ViewTransitionName)

Set view-transition-name.

pub fn copy_view_transition_name_from(&mut self, other: &UI)

Set view-transition-name from other struct.

pub fn reset_view_transition_name(&mut self, other: &UI)

Reset view-transition-name from the initial struct.

pub fn clone_view_transition_name(&self) -> ViewTransitionName

Get the computed value for view-transition-name.

pub fn view_transition_name_equals(&self, other: &UI) -> bool

Whether self and other have the same computed value for view-transition-name.

Source

impl UI

pub fn animation_delay_iter(&self) -> AnimationDelayIter<'_>

Iterate over the values of animation-delay.

pub fn animation_delay_mod(&self, index: usize) -> Time

Get a value mod index for the property animation-delay.

pub fn animation_direction_iter(&self) -> AnimationDirectionIter<'_>

Iterate over the values of animation-direction.

pub fn animation_direction_mod(&self, index: usize) -> AnimationDirection

Get a value mod index for the property animation-direction.

pub fn animation_duration_iter(&self) -> AnimationDurationIter<'_>

Iterate over the values of animation-duration.

pub fn animation_duration_mod( &self, index: usize, ) -> GenericAnimationDuration<Time>

Get a value mod index for the property animation-duration.

pub fn animation_fill_mode_iter(&self) -> AnimationFillModeIter<'_>

Iterate over the values of animation-fill-mode.

pub fn animation_fill_mode_mod(&self, index: usize) -> AnimationFillMode

Get a value mod index for the property animation-fill-mode.

pub fn animation_iteration_count_iter(&self) -> AnimationIterationCountIter<'_>

Iterate over the values of animation-iteration-count.

pub fn animation_iteration_count_mod( &self, index: usize, ) -> AnimationIterationCount

Get a value mod index for the property animation-iteration-count.

pub fn animation_name_iter(&self) -> AnimationNameIter<'_>

Iterate over the values of animation-name.

pub fn animation_name_mod(&self, index: usize) -> AnimationName

Get a value mod index for the property animation-name.

pub fn animation_play_state_iter(&self) -> AnimationPlayStateIter<'_>

Iterate over the values of animation-play-state.

pub fn animation_play_state_mod(&self, index: usize) -> AnimationPlayState

Get a value mod index for the property animation-play-state.

pub fn animation_range_end_iter(&self) -> AnimationRangeEndIter<'_>

Iterate over the values of animation-range-end.

pub fn animation_range_end_mod( &self, index: usize, ) -> GenericAnimationRangeEnd<LengthPercentage>

Get a value mod index for the property animation-range-end.

pub fn animation_range_start_iter(&self) -> AnimationRangeStartIter<'_>

Iterate over the values of animation-range-start.

pub fn animation_range_start_mod( &self, index: usize, ) -> GenericAnimationRangeStart<LengthPercentage>

Get a value mod index for the property animation-range-start.

pub fn animation_timeline_iter(&self) -> AnimationTimelineIter<'_>

Iterate over the values of animation-timeline.

pub fn animation_timeline_mod( &self, index: usize, ) -> GenericAnimationTimeline<LengthPercentage>

Get a value mod index for the property animation-timeline.

pub fn animation_timing_function_iter(&self) -> AnimationTimingFunctionIter<'_>

Iterate over the values of animation-timing-function.

pub fn animation_timing_function_mod( &self, index: usize, ) -> TimingFunction<i32, f32, PiecewiseLinearFunction>

Get a value mod index for the property animation-timing-function.

pub fn transition_behavior_iter(&self) -> TransitionBehaviorIter<'_>

Iterate over the values of transition-behavior.

pub fn transition_behavior_mod(&self, index: usize) -> TransitionBehavior

Get a value mod index for the property transition-behavior.

pub fn transition_delay_iter(&self) -> TransitionDelayIter<'_>

Iterate over the values of transition-delay.

pub fn transition_delay_mod(&self, index: usize) -> Time

Get a value mod index for the property transition-delay.

pub fn transition_duration_iter(&self) -> TransitionDurationIter<'_>

Iterate over the values of transition-duration.

pub fn transition_duration_mod(&self, index: usize) -> Time

Get a value mod index for the property transition-duration.

pub fn transition_property_iter(&self) -> TransitionPropertyIter<'_>

Iterate over the values of transition-property.

pub fn transition_property_mod(&self, index: usize) -> TransitionProperty

Get a value mod index for the property transition-property.

pub fn transition_timing_function_iter( &self, ) -> TransitionTimingFunctionIter<'_>

Iterate over the values of transition-timing-function.

pub fn transition_timing_function_mod( &self, index: usize, ) -> TimingFunction<i32, f32, PiecewiseLinearFunction>

Get a value mod index for the property transition-timing-function.

pub fn animation_composition_iter(&self) -> AnimationCompositionIter<'_>

Iterate over the values of animation-composition.

pub fn animation_composition_mod(&self, index: usize) -> AnimationComposition

Get a value mod index for the property animation-composition.

pub fn specifies_animations(&self) -> bool

Returns whether there is any animation specified with animation-name other than none.

pub fn specifies_transitions(&self) -> bool

Returns whether there are any transitions specified.

pub fn has_initial_animation_timeline(&self) -> bool

Returns whether animation-timeline is initial value. We need this information to resolve animation-duration.

pub fn animations_equals(&self, other: &UI) -> bool

Returns true if animation properties are equal between styles, but without considering keyframe data and animation-timeline.