Module values

Module values 

Computed value types that exist as standalone re-exports.

Structs

CSSPixelLength
The computed <length> value.
Color
An absolutely specified color, using either rgb(), rgba(), lab(), lch(), oklab(), oklch() or color().
ContentDistribution
Shared value for the align-content and justify-content properties.
Display
FontFamily
Specifies a prioritized list of font family names or generic family names.
FontStyle
The computed value of font-style.
FontWeight
A value for the font-weight property per:
GridAutoFlow
Controls how the auto-placement algorithm works specifying exactly how auto-placed items get flowed into the grid: [ row | column ] || dense https://drafts.csswg.org/css-grid-2/#grid-auto-flow-property
JustifyItems
The computed value for the justify-items property.
LengthPercentage
A <length-percentage> value. This can be either a <length>, a <percentage>, or a combination of both via calc().
SelfAlignment
The specified value of the {align,justify}-self properties.
TextDecorationLine
Specified keyword values for the text-decoration-line property.

Enums

BorderStyle
A specified value for a single side of a border-style property.
Clear
https://drafts.csswg.org/css2/#propdef-clear
Float
https://drafts.csswg.org/css-box/#propdef-float
Overflow
The value for the overflow-x / overflow-y properties.
Position

Type Aliases

FlexBasis
A computed value for the flex-basis property.
Length
An alias of computed <length> value.
LengthPercentageOrAuto
A computed type for <length-percentage> | auto.
LineHeight
A computed value for the line-height property.
Margin
A computed type for margin properties.
MaxSize
A computed value for max-width or max-height property.
NonNegativeLength
A wrapper of Length, whose value must be >= 0.
NonNegativeLengthPercentage
A wrapper of LengthPercentage, whose value must be >= 0.
Opacity
A type used for opacity.
Size
A computed value for min-width, min-height, width or height property.
TextAlign
The computed value of text-align.
Transform
A computed CSS transform