pub struct CSSPixelLength(/* private fields */);Expand description
The computed <length> value.
Implementations
Sourceimpl CSSPixelLength
impl CSSPixelLength
Sourcepub fn new(px: f32) -> CSSPixelLength
pub fn new(px: f32) -> CSSPixelLength
Return a new CSSPixelLength.
Sourcepub fn normalized(self) -> CSSPixelLength
pub fn normalized(self) -> CSSPixelLength
Returns a normalized (NaN turned to zero) version of this length.
Sourcepub fn finite(self) -> CSSPixelLength
pub fn finite(self) -> CSSPixelLength
Returns a finite (normalized and clamped to float min and max) version of this length.
Sourcepub fn scale_by(self, scale: f32) -> CSSPixelLength
pub fn scale_by(self, scale: f32) -> CSSPixelLength
Scale the length by a given amount.
Sourcepub fn zoom(self, zoom: Zoom) -> CSSPixelLength
pub fn zoom(self, zoom: Zoom) -> CSSPixelLength
Zooms a particular length.
Sourcepub fn abs(self) -> CSSPixelLength
pub fn abs(self) -> CSSPixelLength
Return the absolute value of this length.
Sourcepub fn clamp_to_non_negative(self) -> CSSPixelLength
pub fn clamp_to_non_negative(self) -> CSSPixelLength
Return the clamped value of this length.
Sourcepub fn min(self, other: CSSPixelLength) -> CSSPixelLength
pub fn min(self, other: CSSPixelLength) -> CSSPixelLength
Returns the minimum between self and other.
Sourcepub fn max(self, other: CSSPixelLength) -> CSSPixelLength
pub fn max(self, other: CSSPixelLength) -> CSSPixelLength
Returns the maximum between self and other.
Sourcepub fn max_assign(&mut self, other: CSSPixelLength)
pub fn max_assign(&mut self, other: CSSPixelLength)
Sets self to the maximum between self and other.
Sourcepub fn clamp_between_extremums(
self,
min_size: CSSPixelLength,
max_size: Option<CSSPixelLength>,
) -> CSSPixelLength
pub fn clamp_between_extremums( self, min_size: CSSPixelLength, max_size: Option<CSSPixelLength>, ) -> CSSPixelLength
Clamp the value to a lower bound and an optional upper bound.
Can be used for example with min-width and max-width.
Sourcepub fn clamp_below_max(self, max_size: Option<CSSPixelLength>) -> CSSPixelLength
pub fn clamp_below_max(self, max_size: Option<CSSPixelLength>) -> CSSPixelLength
Clamp the value to an optional upper bound.
Can be used for example with max-width.