pub struct FontWeight(/* private fields */);Expand description
A value for the font-weight property per:
https://drafts.csswg.org/css-fonts-4/#propdef-font-weight
cbindgen:derive-lt cbindgen:derive-lte cbindgen:derive-gt cbindgen:derive-gte
Implementations
Sourceimpl FontWeight
impl FontWeight
Sourcepub const NORMAL: FontWeight
pub const NORMAL: FontWeight
The normal keyword.
Sourcepub const BOLD: FontWeight
pub const BOLD: FontWeight
The bold value.
Sourcepub const BOLD_THRESHOLD: FontWeight
pub const BOLD_THRESHOLD: FontWeight
The threshold from which we consider a font bold.
Sourcepub const PREFER_BOLD_THRESHOLD: FontWeight
pub const PREFER_BOLD_THRESHOLD: FontWeight
The threshold above which CSS font matching prefers bolder faces over lighter ones.
Sourcepub fn normal() -> FontWeight
pub fn normal() -> FontWeight
Returns the normal keyword value.
Sourcepub fn from_float(v: f32) -> FontWeight
pub fn from_float(v: f32) -> FontWeight
Construct a valid weight from a float value.
Sourcepub fn bolder(self) -> FontWeight
pub fn bolder(self) -> FontWeight
Return the bolder weight.
See the table in: https://drafts.csswg.org/css-fonts-4/#font-weight-numeric-values
Sourcepub fn lighter(self) -> FontWeight
pub fn lighter(self) -> FontWeight
Return the lighter weight.
See the table in: https://drafts.csswg.org/css-fonts-4/#font-weight-numeric-values