pub struct TextDecorationLine(/* private fields */);Expand description
Specified keyword values for the text-decoration-line property.
Implementations
Sourceimpl TextDecorationLine
impl TextDecorationLine
Sourcepub const NONE: TextDecorationLine
pub const NONE: TextDecorationLine
No text decoration line is specified.
Sourcepub const UNDERLINE: TextDecorationLine
pub const UNDERLINE: TextDecorationLine
underline
Sourcepub const OVERLINE: TextDecorationLine
pub const OVERLINE: TextDecorationLine
overline
Sourcepub const LINE_THROUGH: TextDecorationLine
pub const LINE_THROUGH: TextDecorationLine
line-through
Sourcepub const BLINK: TextDecorationLine
pub const BLINK: TextDecorationLine
blink
Sourcepub const SPELLING_ERROR: TextDecorationLine
pub const SPELLING_ERROR: TextDecorationLine
spelling-error
Sourcepub const GRAMMAR_ERROR: TextDecorationLine
pub const GRAMMAR_ERROR: TextDecorationLine
grammar-error
Sourceimpl TextDecorationLine
impl TextDecorationLine
Sourcepub const fn empty() -> TextDecorationLine
pub const fn empty() -> TextDecorationLine
Get a flags value with all bits unset.
Sourcepub const fn all() -> TextDecorationLine
pub const fn all() -> TextDecorationLine
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<TextDecorationLine>
pub const fn from_bits(bits: u8) -> Option<TextDecorationLine>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> TextDecorationLine
pub const fn from_bits_truncate(bits: u8) -> TextDecorationLine
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> TextDecorationLine
pub const fn from_bits_retain(bits: u8) -> TextDecorationLine
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<TextDecorationLine>
pub fn from_name(name: &str) -> Option<TextDecorationLine>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: TextDecorationLine) -> bool
pub const fn intersects(&self, other: TextDecorationLine) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: TextDecorationLine) -> bool
pub const fn contains(&self, other: TextDecorationLine) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: TextDecorationLine)
pub fn insert(&mut self, other: TextDecorationLine)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: TextDecorationLine)
pub fn remove(&mut self, other: TextDecorationLine)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: TextDecorationLine)
pub fn toggle(&mut self, other: TextDecorationLine)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: TextDecorationLine, value: bool)
pub fn set(&mut self, other: TextDecorationLine, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: TextDecorationLine) -> TextDecorationLine
pub const fn intersection(self, other: TextDecorationLine) -> TextDecorationLine
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: TextDecorationLine) -> TextDecorationLine
pub const fn union(self, other: TextDecorationLine) -> TextDecorationLine
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: TextDecorationLine) -> TextDecorationLine
pub const fn difference(self, other: TextDecorationLine) -> TextDecorationLine
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: TextDecorationLine,
) -> TextDecorationLine
pub const fn symmetric_difference( self, other: TextDecorationLine, ) -> TextDecorationLine
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> TextDecorationLine
pub const fn complement(self) -> TextDecorationLine
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl TextDecorationLine
impl TextDecorationLine
Sourcepub const fn iter(&self) -> Iter<TextDecorationLine>
pub const fn iter(&self) -> Iter<TextDecorationLine>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TextDecorationLine>
pub const fn iter_names(&self) -> IterNames<TextDecorationLine>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl TextDecorationLine
impl TextDecorationLine
Sourcepub fn none() -> TextDecorationLine
pub fn none() -> TextDecorationLine
Returns the initial value of text-decoration-line