pub struct Arc<T>where
T: ?Sized,{ /* private fields */ }Expand description
Arc wrapper used by Stylo. An atomically reference counted shared pointer
See the documentation for Arc in the standard library. Unlike the
standard library Arc, this Arc does not support weak reference counting.
See the discussion in https://github.com/rust-lang/rust/pull/60594 for the usage of PhantomData.
cbindgen:derive-eq=false cbindgen:derive-neq=false
Implementations
Sourceimpl<T> Arc<T>
impl<T> Arc<T>
Sourcepub fn new_leaked(data: T) -> Arc<T>
pub fn new_leaked(data: T) -> Arc<T>
Construct an intentionally-leaked arc.
Sourcepub fn into_raw(this: Arc<T>) -> *const T
pub fn into_raw(this: Arc<T>) -> *const T
Convert the Arc
Note: This returns a pointer to the data T, which is offset in the allocation.
Sourcepub unsafe fn from_raw(ptr: *const T) -> Arc<T>
pub unsafe fn from_raw(ptr: *const T) -> Arc<T>
Reconstruct the Arc
Note: This raw pointer will be offset in the allocation and must be preceded by the atomic count.
Sourcepub unsafe fn from_raw_addrefed(ptr: *const T) -> Arc<T>
pub unsafe fn from_raw_addrefed(ptr: *const T) -> Arc<T>
Like from_raw, but returns an addrefed arc instead.
Sourcepub unsafe fn new_static<F>(alloc: F, data: T) -> Arc<T>
pub unsafe fn new_static<F>(alloc: F, data: T) -> Arc<T>
Create a new static Arcalloc
function.
alloc must return a pointer into a static allocation suitable for
storing data with the Layout passed into it. The pointer returned by
alloc will not be freed.
Sourcepub fn borrow_arc<'a>(&'a self) -> ArcBorrow<'a, T>
pub fn borrow_arc<'a>(&'a self) -> ArcBorrow<'a, T>
Produce a pointer to the data that can be converted back
to an Arc. This is basically an &Arc<T>, without the extra indirection.
It has the benefits of an &T but also knows about the underlying refcount
and can be converted into more Arc<T>s if necessary.
Sourceimpl<T> Arc<T>where
T: ?Sized,
impl<T> Arc<T>where
T: ?Sized,
Sourcepub fn mark_as_intentionally_leaked(&self)
pub fn mark_as_intentionally_leaked(&self)
Marks this Arc as intentionally leaked for the purposes of refcount
logging.
It’s a logic error to call this more than once, but it’s not unsafe, as it’d just report negative leaks.
Sourceimpl<T> Arc<T>where
T: Clone,
impl<T> Arc<T>where
T: Clone,
Sourcepub fn make_mut(this: &mut Arc<T>) -> &mut T
pub fn make_mut(this: &mut Arc<T>) -> &mut T
Makes a mutable reference to the Arc, cloning if necessary
This is functionally equivalent to Arc::make_mut from the standard library.
If this Arc is uniquely owned, make_mut() will provide a mutable
reference to the contents. If not, make_mut() will create a new Arc
with a copy of the contents, update this to point to it, and provide
a mutable reference to its contents.
This is useful for implementing copy-on-write schemes where you wish to
avoid copying things if your Arc is not shared.
Sourceimpl<T> Arc<T>where
T: ?Sized,
impl<T> Arc<T>where
T: ?Sized,
Sourceimpl<H, T> Arc<HeaderSlice<H, T>>
impl<H, T> Arc<HeaderSlice<H, T>>
Sourcepub fn from_header_and_iter_alloc<F, I>(
alloc: F,
header: H,
items: I,
num_items: usize,
is_static: bool,
) -> Arc<HeaderSlice<H, T>>
pub fn from_header_and_iter_alloc<F, I>( alloc: F, header: H, items: I, num_items: usize, is_static: bool, ) -> Arc<HeaderSlice<H, T>>
Creates an Arc for a HeaderSlice using the given header struct and iterator to generate the slice.
is_static indicates whether to create a static Arc.
alloc is used to get a pointer to the memory into which the
dynamically sized ArcInner<HeaderSlice<H, T>> value will be
written. If is_static is true, then alloc must return a
pointer into some static memory allocation. If it is false,
then alloc must return an allocation that can be dellocated
by calling Box::from_raw::<ArcInner<HeaderSlice<H, T>>> on it.
Sourcepub fn from_header_and_iter_with_size<I>(
header: H,
items: I,
num_items: usize,
) -> Arc<HeaderSlice<H, T>>where
I: Iterator<Item = T>,
pub fn from_header_and_iter_with_size<I>(
header: H,
items: I,
num_items: usize,
) -> Arc<HeaderSlice<H, T>>where
I: Iterator<Item = T>,
Creates an Arc for a HeaderSlice using the given header struct and iterator to generate the slice. Panics if num_items doesn’t match the number of items.
Sourcepub fn from_header_and_iter<I>(header: H, items: I) -> Arc<HeaderSlice<H, T>>where
I: Iterator<Item = T> + ExactSizeIterator,
pub fn from_header_and_iter<I>(header: H, items: I) -> Arc<HeaderSlice<H, T>>where
I: Iterator<Item = T> + ExactSizeIterator,
Creates an Arc for a HeaderSlice using the given header struct and iterator to generate the slice. The resulting Arc will be fat.